@@ -111,6 +111,14 @@ def test_clean_multiparts(bucket, create_tempfile):
     assert "Uploads" not in response, "The multipart clean failed."
 
 
+@mock_s3
+def test_clean_multiparts_empty_bucket(bucket):
+    bucket.create()
+
+    status_dict = bucket.clean_multiparts()
+    assert status_dict == {}
+
+
 @mock_s3
 def test_get_bucket_size(bucket, create_tempfile):
     bucket.create()
@@ -136,6 +144,23 @@ def test_get_bucket_size_empty(bucket):
     assert bucket_size == 0
 
 
+@mock_s3
+def test_get_bucket_many_page(bucket, create_tempfile):
+    bucket.create()
+
+    with create_tempfile("txt") as temp1:
+        with open(temp1.name, "w") as w:
+            for n in range(0, 20):
+                w.write(str(1))
+                w.write(",")
+
+        status = bucket.upload_file(temp1.name, temp1.name)
+        assert status is True
+
+    bucket_size = bucket.size(items_per_page=5)
+    assert bucket_size == 40
+
+
 @mock_s3
 def test_list_buckets(bucket, bucket2):
     bucket.create()
